@@ -1,29 +1,16 @@
 /* This file is part of the KDE libraries
- *  Copyright (c) 1997 Patrick Dowler <dowler@morgul.fsh.uvic.ca>
- *  Copyright (c) 2000 Dirk Mueller <mueller@kde.org>
- *  Copyright (c) 2002 Marc Mutz <mutz@kde.org>
+ *  SPDX-FileCopyrightText: 1997 Patrick Dowler <dowler@morgul.fsh.uvic.ca>
+ *  SPDX-FileCopyrightText: 2000 Dirk Mueller <mueller@kde.org>
+ *  SPDX-FileCopyrightText: 2002 Marc Mutz <mutz@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef kpNumInput_H
 #define kpNumInput_H
 
-#include <QWidget>
 #include <QSpinBox>
+#include <QWidget>
 
 class QSlider;
 
@@ -283,7 +270,6 @@ Q_SIGNALS:
      */
     void valueChanged(int);
 
-
 private Q_SLOTS:
     void spinValueChanged(int);
 
@@ -361,8 +347,7 @@ public:
      * @param precision number of digits after the decimal point
      * @param parent parent QWidget
      */
-    kpDoubleNumInput(double lower, double upper, double value, QWidget *parent = nullptr, double singleStep = 0.01,
-                    int precision = 2);
+    kpDoubleNumInput(double lower, double upper, double value, QWidget *parent = nullptr, double singleStep = 0.01, int precision = 2);
 
     /**
      * destructor
@@ -393,11 +378,11 @@ public:
     QString specialValueText() const;
 
     /**
-    * @param min  minimum value
-    * @param max  maximum value
-    * @param singleStep step size for the QSlider
-    * @param slider whether the slider is created or not
-    */
+     * @param min  minimum value
+     * @param max  maximum value
+     * @param singleStep step size for the QSlider
+     * @param slider whether the slider is created or not
+     */
     void setRange(double min, double max, double singleStep = 1);
 
     /**
@@ -474,9 +459,9 @@ protected:
     void resizeEvent(QResizeEvent *) override;
 
     friend class kpDoubleLine;
+
 private:
-    void initWidget(double value, double lower, double upper,
-                    double singleStep, int precision);
+    void initWidget(double value, double lower, double upper, double singleStep, int precision);
     double mapSliderToSpin(int) const;
 
 private:
@@ -487,5 +472,4 @@ private:
     Q_DISABLE_COPY(kpDoubleNumInput)
 };
 
-
 #endif // kpNumInput_H
